General documentation for MEANtools
===================================

Read the documentation here:

https://meantools.readthedocs.io/en/latest/

Maintainer
==========
Dr. Kumar Saurabh Singh (kumar.singh@wur.nl)

Principal Investigator
======================
Dr. Marnix Medema (marnix.medema@wur.nl)
